==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MoneyFlowIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MoneyFlowIndexIndicator, _super);
    function MoneyFlowIndexIndicator() {
        return _super.call(this) || this;
    }
    MoneyFlowIndexIndicator.prototype.get_tb = function () {
        return 1;
    };
    MoneyFlowIndexIndicator.prototype.get_t4 = function () {
        return new MoneyFlowIndexIndicatorStrategy();
    };
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "t4", {
        get: function () {
            return this.get_t4();
        },
        enumerable: false,
        configurable: true
    });
    MoneyFlowIndexIndicator.prototype.get_uh = function () {
        return MoneyFlowIndexIndicator.$;
    };
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "up", {
        get: function () {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.uq));
        },
        set: function (a) {
            this.h(MoneyFlowIndexIndicator.uq, a);
        },
        enumerable: false,
        configurable: true
    });
    MoneyFlowIndexIndicator.prototype.ua = function () {
        return this.up;
    };
    MoneyFlowIndexIndicator.prototype.uj = function (a) {
        this.up = a;
    };
    MoneyFlowIndexIndicator.$t = markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.uq = StrategyBasedIndicator.um(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
}(StrategyBasedIndicator));
export { MoneyFlowIndexIndicator };

==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MoneyFlowIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MoneyFlowIndexIndicator, _super);
    function MoneyFlowIndexIndicator() {
        return _super.call(this) || this;
    }
    MoneyFlowIndexIndicator.prototype.get_to = function () {
        return 1;
    };
    MoneyFlowIndexIndicator.prototype.get_uh = function () {
        return new MoneyFlowIndexIndicatorStrategy();
    };
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    MoneyFlowIndexIndicator.prototype.get_uu = function () {
        return MoneyFlowIndexIndicator.$;
    };
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "uu", {
        get: function () {
            return this.get_uu();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoneyFlowIndexIndicator.prototype, "u2", {
        get: function () {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.u3));
        },
        set: function (a) {
            this.h(MoneyFlowIndexIndicator.u3, a);
        },
        enumerable: false,
        configurable: true
    });
    MoneyFlowIndexIndicator.prototype.un = function () {
        return this.u2;
    };
    MoneyFlowIndexIndicator.prototype.uw = function (a) {
        this.u2 = a;
    };
    MoneyFlowIndexIndicator.$t = markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.u3 = StrategyBasedIndicator.uz(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
}(StrategyBasedIndicator));
export { MoneyFlowIndexIndicator };
